<?php

namespace Wun\Wun\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Wun\Wun\Interfaces\SystemsettingsRepositoryInterface;
use Wun\Wun\Repositories\Presenter\SystemsettingsItemTransformer;

/**
 * Pubic API controller class.
 */
class SystemsettingsPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Wun\Systemsettings\Interfaces\SystemsettingsRepositoryInterface $systemsettings
     *
     * @return type
     */
    public function __construct(SystemsettingsRepositoryInterface $systemsettings)
    {
        $this->repository = $systemsettings;
        parent::__construct();
    }

    /**
     * Show systemsettings's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $systemsettings = $this->repository
            ->setPresenter('\\Wun\\Wun\\Repositories\\Presenter\\SystemsettingsListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $systemsettings['code'] = 2000;
        return response()->json($systemsettings)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show systemsettings.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $systemsettings = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($systemsettings)) {
            $systemsettings         = $this->itemPresenter($module, new SystemsettingsItemTransformer);
            $systemsettings['code'] = 2001;
            return response()->json($systemsettings)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
