<?php

namespace Wun\Wun\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Wun\Wun\Http\Requests\SystemsettingsRequest;
use Wun\Wun\Interfaces\SystemsettingsRepositoryInterface;
use Wun\Wun\Models\Systemsettings;

/**
 * User API controller class.
 */
class SystemsettingsUserController extends BaseController
{
    /**
     * Initialize systemsettings controller.
     *
     * @param type SystemsettingsRepositoryInterface $systemsettings
     *
     * @return type
     */
    public function __construct(SystemsettingsRepositoryInterface $systemsettings)
    {
        $this->repository = $systemsettings;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Wun\Wun\Repositories\Criteria\SystemsettingsUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of systemsettings.
     *
     * @return json
     */
    public function index(SystemsettingsRequest $request)
    {
        $systemsettings  = $this->repository
            ->setPresenter('\\Wun\\Wun\\Repositories\\Presenter\\SystemsettingsListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $systemsettings['code'] = 2000;
        return response()->json($systemsettings) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display systemsettings.
     *
     * @param Request $request
     * @param Model   Systemsettings
     *
     * @return Json
     */
    public function show(SystemsettingsRequest $request, Systemsettings $systemsettings)
    {

        if ($systemsettings->exists) {
            $systemsettings         = $systemsettings->presenter();
            $systemsettings['code'] = 2001;
            return response()->json($systemsettings)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new systemsettings.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(SystemsettingsRequest $request, Systemsettings $systemsettings)
    {
        $systemsettings         = $systemsettings->presenter();
        $systemsettings['code'] = 2002;
        return response()->json($systemsettings)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new systemsettings.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(SystemsettingsRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $systemsettings          = $this->repository->create($attributes);
            $systemsettings          = $systemsettings->presenter();
            $systemsettings['code']  = 2004;

            return response()->json($systemsettings)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show systemsettings for editing.
     *
     * @param Request $request
     * @param Model   $systemsettings
     *
     * @return json
     */
    public function edit(SystemsettingsRequest $request, Systemsettings $systemsettings)
    {
        if ($systemsettings->exists) {
            $systemsettings         = $systemsettings->presenter();
            $systemsettings['code'] = 2003;
            return response()-> json($systemsettings)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the systemsettings.
     *
     * @param Request $request
     * @param Model   $systemsettings
     *
     * @return json
     */
    public function update(SystemsettingsRequest $request, Systemsettings $systemsettings)
    {
        try {

            $attributes = $request->all();

            $systemsettings->update($attributes);
            $systemsettings         = $systemsettings->presenter();
            $systemsettings['code'] = 2005;

            return response()->json($systemsettings)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the systemsettings.
     *
     * @param Request $request
     * @param Model   $systemsettings
     *
     * @return json
     */
    public function destroy(SystemsettingsRequest $request, Systemsettings $systemsettings)
    {

        try {

            $t = $systemsettings->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('wun::systemsettings.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
