<?php

namespace Wun\Wun\Http\Controllers;
use Litepie\Wun\Http\Requests\SystemsettingsRequest;
use Litepie\Wun\Models\Systemsettings;

trait SystemsettingsWorkflow {
	
    /**
     * Workflow controller function for systemsettings.
     *
     * @param Model   $systemsettings
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(SystemsettingsRequest $request, Systemsettings $systemsettings, $step)
    {

        try {

            $systemsettings->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('wun::systemsettings.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/systemsettings/systemsettings/' . $systemsettings->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/systemsettings/systemsettings/' . $systemsettings->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for systemsettings.
     *
     * @param Model   $systemsettings
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Systemsettings $systemsettings, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $systemsettings->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('wun::systemsettings.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('wun::admin.systemsettings.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('wun::admin.systemsettings.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('wun::admin.systemsettings.message', $data)->render();

        }

    }
}