<?php

namespace Wun\Wun\Policies;

use App\User;
use Wun\Wun\Models\Systemsettings;

class SystemsettingsPolicy
{

    /**
     * Determine if the given user can view the systemsettings.
     *
     * @param User $user
     * @param Systemsettings $systemsettings
     *
     * @return bool
     */
    public function view(User $user, Systemsettings $systemsettings)
    {
        if ($user->canDo('wun.systemsettings.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $systemsettings->user_id;
    }

    /**
     * Determine if the given user can create a systemsettings.
     *
     * @param User $user
     * @param Systemsettings $systemsettings
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('wun.systemsettings.create');
    }

    /**
     * Determine if the given user can update the given systemsettings.
     *
     * @param User $user
     * @param Systemsettings $systemsettings
     *
     * @return bool
     */
    public function update(User $user, Systemsettings $systemsettings)
    {
        if ($user->canDo('wun.systemsettings.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $systemsettings->user_id;
    }

    /**
     * Determine if the given user can delete the given systemsettings.
     *
     * @param User $user
     * @param Systemsettings $systemsettings
     *
     * @return bool
     */
    public function destroy(User $user, Systemsettings $systemsettings)
    {
        if ($user->canDo('wun.systemsettings.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $systemsettings->user_id;
    }

    /**
     * Determine if the given user can verify the given systemsettings.
     *
     * @param User $user
     * @param Systemsettings $systemsettings
     *
     * @return bool
     */
    public function verify(User $user, Systemsettings $systemsettings)
    {
        if ($user->canDo('wun.systemsettings.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('wun.systemsettings.verify') 
        && $user->is('manager')
        && $systemsettings->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given systemsettings.
     *
     * @param User $user
     * @param Systemsettings $systemsettings
     *
     * @return bool
     */
    public function approve(User $user, Systemsettings $systemsettings)
    {
        if ($user->canDo('wun.systemsettings.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
