<?php

namespace Wun\Wun\Providers;

use Illuminate\Support\ServiceProvider;

class WunServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'wun');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'wun');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('wun', function ($app) {
            return $this->app->make('Wun\Wun\Wun');
        });

        // Bind Systemsettings to repository
        $this->app->bind(
            \Wun\Wun\Interfaces\SystemsettingsRepositoryInterface::class,
            \Wun\Wun\Repositories\Eloquent\SystemsettingsRepository::class
        );

        $this->app->register(\Wun\Wun\Providers\AuthServiceProvider::class);
        $this->app->register(\Wun\Wun\Providers\EventServiceProvider::class);
        $this->app->register(\Wun\Wun\Providers\RouteServiceProvider::class);
        // $this->app->register(\Wun\Wun\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['wun'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('wun/wun.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/wun')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/wun')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
