<?php

namespace Wun\Wun\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Wun\Wun\Models\Systemsettings;

class SystemsettingsAction
{
    /**
     * Perform the complete action.
     *
     * @param Systemsettings $systemsettings
     *
     * @return Systemsettings
     */
    public function complete(Systemsettings $systemsettings)
    {
        try {
            $systemsettings->status = 'complete';
            return $systemsettings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Systemsettings $systemsettings
     *
     * @return Systemsettings
     */public function verify(Systemsettings $systemsettings)
    {
        try {
            $systemsettings->status = 'verify';
            return $systemsettings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Systemsettings $systemsettings
     *
     * @return Systemsettings
     */public function approve(Systemsettings $systemsettings)
    {
        try {
            $systemsettings->status = 'approve';
            return $systemsettings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Systemsettings $systemsettings
     *
     * @return Systemsettings
     */public function publish(Systemsettings $systemsettings)
    {
        try {
            $systemsettings->status = 'publish';
            return $systemsettings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Systemsettings $systemsettings
     *
     * @return Systemsettings
     */
    public function archive(Systemsettings $systemsettings)
    {
        try {
            $systemsettings->status = 'archive';
            return $systemsettings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Systemsettings $systemsettings
     *
     * @return Systemsettings
     */
    public function unpublish(Systemsettings $systemsettings)
    {
        try {
            $systemsettings->status = 'unpublish';
            return $systemsettings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
